@@ -5,7 +5,7 @@ use strict;
 use warnings;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 my$self;
 
@@ -38,22 +38,23 @@ sub new{
 
 sub validate_data{
 	($self->{totalTransactions}=~/^\d+$/)
-		or die("Error: \$self->{totalTransactions} invalid value!\n");
+		or die("Error: \$apriori->{totalTransactions} invalid value!\n");
 	($self->{minSupport}=~/^\d{1,3}\.?\d*$/
 	&&($self->{minSupport}>=0&&$self->{minSupport}<=100))
-		or die("Error: \$self->{minSupport} invalid value!\n");
+		or die("Error: \$apriori->{minSupport} invalid value!\n");
 	($self->{minConfidence}=~/^\d{1,3}\.?\d*$/
 	&&($self->{minConfidence}>=0&&$self->{minConfidence}<=100))
-		or die("Error: \$self->{minConfidence} invalid value!\n");
+		or die("Error: \$apriori->{minConfidence} invalid value!\n");
 	($self->{itemsKeyDescription})
-		or die("Error: \$self->{itemsKeyDescription} is not defined!\n");
+		or die("Error: \$apriori->{itemsKeyDescription} is not defined!\n");
 	($self->{itemsKeyTransactions})
-		or die("Error: \$self->{itemsKeyTransactions} is not defined!\n");
+		or die("Error: \$apriori->{itemsKeyTransactions} is not defined!\n");
 }
 
 sub generate_rules{
 	$self->validate_data;
 	my @candidateItemsetSizeOne = $self->data_persistence;
+	@candidateItemsetSizeOne = grep{((scalar(@{$self->{itemsKeyTransactions}{$_}})/$self->{totalTransactions})*100)>=$self->{minSupport}}@candidateItemsetSizeOne;
 	if($self->{messages}&&!$self->{recursively}){
 		my $quantityItems = scalar(@candidateItemsetSizeOne);
 		$self->{quantityPossibleRules} = ((3**$quantityItems)-(2**($quantityItems+1))+1);
@@ -74,17 +75,18 @@ sub association_rules_itemset_size{
 			or die("Error: Invalid number of arguments! It is expected a number representing the size of itemset!\n");
 		@candidateItemsetSizeOne = $self->data_persistence;
 		((scalar(@candidateItemsetSizeOne)>=$_[1])&&($_[1]>=2))
-			or die("Error: quantity of items should be greater or equal the size of itemset and size of the itemset greater or equal to 2!\n");
+			or die("Error: Quantity of items should be greater or equal the size of itemset and size of the itemset greater or equal to 2!\n");
+		@candidateItemsetSizeOne = grep{((scalar(@{$self->{itemsKeyTransactions}{$_}})/$self->{totalTransactions})*100)>=$self->{minSupport}}@candidateItemsetSizeOne;
 		$self->{itemsetSize} = $_[1];
 	}
-	my @newCandidateItemsetSizeOne = ();
+	my @newCandidateItemsetSizeOne;
 	if($self->{messages}){
 		print "\nItemset size ", $self->{itemsetSize}, ", ", scalar(@candidateItemsetSizeOne), " items ";
 		print "\nProcessing... ";
 	}
 	for(my$itemsetSize=2;$itemsetSize<=$self->{itemsetSize};$itemsetSize++){
 		my $code=<<'CODE';
-my @candidateItemset=();
+my @candidateItemset;
 $self->{implications}={};
 for(my$k=0;$k<=$#candidateItemsetSizeOne;$k++){
 	push @candidateItemset,$candidateItemsetSizeOne[$k];
@@ -99,48 +101,38 @@ for(my$l=0;$l<=$#candidateItemsetSizeOne;$l++){
 CODE
 		}
 		$code.=<<'CODE';
-for(my$subsetSize=0;$subsetSize<$#candidateItemset;$subsetSize++){
-	my @antecedent=();
-	my @consequent=();
-	for(my$m=0;$m<=$subsetSize;$m++){
+for(my$antecedentSize=0;$antecedentSize<$#candidateItemset;$antecedentSize++){
+	my @antecedent;
+	my @consequent;
+	for(my$m=0;$m<=$antecedentSize;$m++){
 		push @antecedent,$candidateItemset[$m];
 	}
 	@antecedent = sort @antecedent;
-	@consequent = grep!($_~~@antecedent),@candidateItemset;
+	@consequent = grep{!($_~~@antecedent)}@candidateItemset;
 	@consequent = sort @consequent;
-	if("@consequent" ~~ @{$self->{implications}{"@antecedent"}}){
-		next;
-	}
+	next if("@consequent" ~~ @{$self->{implications}{"@antecedent"}});
 	push @{$self->{implications}{"@antecedent"}},"@consequent";
 	my @transactions = @{$self->{itemsKeyTransactions}{$antecedent[0]}};
-	my $support = sprintf("%.2f",((scalar(@transactions)/$self->{totalTransactions})*100));
-	if($support < $self->{minSupport} || $support == 0){
-		next;
-	}
-	for(my$item=1;$item<=$#antecedent;$item++){
-		@transactions = grep $_ ~~ @transactions,@{$self->{itemsKeyTransactions}{$antecedent[$item]}};
+	foreach my$item(@antecedent){
+		@transactions = grep{$_~~@transactions}@{$self->{itemsKeyTransactions}{$item}};
 	}
 	my $supportAntecedent = scalar(@transactions);
-	if($supportAntecedent == 0){
-		next;
-	}
-	for(my$item=0;$item<=$#consequent;$item++){
-		@transactions = grep $_ ~~ @transactions,@{$self->{itemsKeyTransactions}{$consequent[$item]}};
+	next if($supportAntecedent == 0);
+	foreach my$item(@consequent){
+		@transactions = grep{$_~~@transactions}@{$self->{itemsKeyTransactions}{$item}};
 	}
 	my $supportConsequent = scalar(@transactions);
-	if($supportConsequent == 0){
-		next;
-	}
-	$support = sprintf("%.2f",(($supportConsequent/$self->{totalTransactions})*100));
+	next if($supportConsequent == 0);
+	my $support = sprintf("%.2f",(($supportConsequent/$self->{totalTransactions})*100));
 	if($support >= $self->{minSupport}){
 		my $confidence = sprintf("%.2f",(($supportConsequent/$supportAntecedent)*100));
 		if($confidence >= $self->{minConfidence}){
 			$self->{rule}++;
 			$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{rule} = ["{ @antecedent } => { @consequent }", $support, $confidence];
 			$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items} = [@antecedent, @consequent];
-			my@items=grep!($_~~@newCandidateItemsetSizeOne),@antecedent;
+			my@items=grep{!($_~~@newCandidateItemsetSizeOne)}@antecedent;
 			push @newCandidateItemsetSizeOne,@items;
-			@items=grep!($_~~@newCandidateItemsetSizeOne),@consequent;
+			@items=grep{!($_~~@newCandidateItemsetSizeOne)}@consequent;
 			push @newCandidateItemsetSizeOne,@items;			
 		}
 	}
@@ -355,9 +347,9 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	$apriori->{totalTransactions}=10; # The total number of transactions
 
-	$apriori->{minSupport}=1.55; # The minimum support
+	$apriori->{minSupport}=1.55; # The minimum support (percent)
 
-	$apriori->{minConfidence}=1.55; # The minimum confidence
+	$apriori->{minConfidence}=1.55; # The minimum confidence (percent)
 
 	$apriori->{output}=1; # The output type (1 - Export to text file delimited by tab; 2 - Export to excel file with chart)(optional)
 
@@ -565,11 +557,11 @@ The total number of transactions.
 
 =head2 minSupport
 
-The minimum support.
+The minimum support (percent).
 
 =head2 minConfidence
 
-The minimum confidence.
+The minimum confidence (percent).
 
 =head2 output
 
@@ -577,9 +569,13 @@ The output type (optional):
 
 =over 4
 
-=item 1- Text file delimited by tab;
+=item 1-
 
-=item 2- Excel file with chart.
+Text file delimited by tab;
+
+=item 2-
+
+Excel file with chart.
 
 =back
 
